@@ -1,6 +1,6 @@
 package Dist::Zilla::Plugin::ReadmeFromPod;
 our $AUTHORITY = 'cpan:FAYLAND';
-$Dist::Zilla::Plugin::ReadmeFromPod::VERSION = '0.32';
+$Dist::Zilla::Plugin::ReadmeFromPod::VERSION = '0.33';
 use Moose;
 use List::Util 1.33 qw( first );
 with 'Dist::Zilla::Role::InstallTool' => { -version => 5 }; # after PodWeaver
@@ -79,8 +79,8 @@ sub setup_installer {
             'html'     => 'html',
             'htm'      => 'html',
             'rtf'      => 'rtf',
-            'txt'      => 'txt',
-            ''         => 'pod',
+            'txt'      => 'text',
+            ''         => 'text',
             'pod'      => 'pod'
         );
         foreach my $e (keys %ext) {
